@@ -21,18 +21,20 @@ import logging
 import subprocess
 import sys
 import warnings
-from importlib import reload
 from logging.handlers import RotatingFileHandler
 
 from pyupdater.client import Client
 
 import ledfx.config as config_helpers
+import ledfx.sentry_config  # noqa: F401
 from ledfx.consts import (
     PROJECT_NAME,
     PROJECT_VERSION,
     REQUIRED_PYTHON_STRING,
     REQUIRED_PYTHON_VERSION,
 )
+from ledfx.core import LedFxCore
+from ledfx.utils import currently_frozen
 
 # Logger Variables
 PYUPDATERLOGLEVEL = 35
@@ -46,11 +48,34 @@ def validate_python() -> None:
         sys.exit(1)
 
 
+def reset_logging():
+    manager = logging.root.manager
+    manager.disabled = logging.NOTSET
+    for logger in manager.loggerDict.values():
+        if isinstance(logger, logging.Logger):
+            logger.setLevel(logging.NOTSET)
+            logger.propagate = True
+            logger.disabled = False
+            logger.filters.clear()
+            handlers = logger.handlers.copy()
+            for handler in handlers:
+                # Copied from `logging.shutdown`.
+                try:
+                    handler.acquire()
+                    handler.flush()
+                    handler.close()
+                except (OSError, ValueError):
+                    pass
+                finally:
+                    handler.release()
+                logger.removeHandler(handler)
+
+
 def setup_logging(loglevel):
     # Create a custom logging level to display pyupdater progress
-    reload(logging)
+    reset_logging()
 
-    console_loglevel = loglevel if loglevel else logging.WARNING
+    console_loglevel = loglevel or logging.WARNING
     console_logformat = "[%(levelname)-8s] %(name)-30s : %(message)s"
 
     file_loglevel = logging.INFO
@@ -93,6 +118,7 @@ def setup_logging(loglevel):
     logging.getLogger("sacn").setLevel(logging.WARNING)
     logging.getLogger("aiohttp.access").setLevel(logging.WARNING)
     logging.getLogger("pyupdater").setLevel(logging.WARNING)
+    logging.getLogger("zeroconf").setLevel(logging.DEBUG)
 
     global _LOGGER
     _LOGGER = logging.getLogger(__name__)
@@ -159,27 +185,35 @@ def parse_args():
         action="store_true",
         help="Disable automated updates and sentry crash logger",
     )
+    parser.add_argument(
+        "--sentry-crash-test",
+        dest="sentry_test",
+        action="store_true",
+        help="This crashes LedFx to test the sentry crash logger",
+    )
     return parser.parse_args()
 
 
-def check_pip_installed():
+def installed_via_pip():
+
+    """Check to see if LedFx is installed via pip
+    Returns:
+        boolean
+    """
     pip_package_command = subprocess.check_output(
         [sys.executable, "-m", "pip", "freeze"]
     )
     installed_packages = [
         r.decode().split("==")[0] for r in pip_package_command.split()
     ]
-    # If the install is from pip, ignore DeprecationWarnings
     if "ledfx" in installed_packages:
-        warnings.filterwarnings("ignore", category=DeprecationWarning)
+        return True
     else:
-        warnings.filterwarnings("default", category=DeprecationWarning)
+        return False
 
 
 def update_ledfx():
 
-    # If we're frozen, we can shut up about DeprecationWarnings
-    warnings.filterwarnings("ignore", category=DeprecationWarning)
     # initialize & refresh in one update, check client
 
     class ClientConfig(object):
@@ -225,22 +259,25 @@ def main():
     setup_logging(args.loglevel)
     config_helpers.load_logger()
 
-    from ledfx.core import LedFxCore
-    from ledfx.utils import currently_frozen
+    if args.sentry_test:
+        """ This will crash LedFx and submit a Sentry error if Sentry is configured """
+        _LOGGER.warning("Steering LedFx into a brick wall")
+        div_by_zero = 1 / 0
+
+    if args.offline_mode is False and currently_frozen():
+
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
+        update_ledfx()
 
     if args.offline_mode:
         _LOGGER.warning(
             "Offline Mode Enabled - Please check for updates regularly."
         )
-        if currently_frozen():
-            # Import sentry if we're frozen and check for updates
-            import ledfx.sentry_config
 
-            update_ledfx()
-    if not currently_frozen():
-        check_pip_installed()
+    if not currently_frozen() and installed_via_pip():
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
 
-    _LOGGER.info("LedFx Core is initialising")
+    _LOGGER.info("LedFx Core is initializing")
 
     ledfx = LedFxCore(config_dir=args.config, host=args.host, port=args.port)
 
