@@ -1,6 +1,7 @@
 import asyncio
 import logging
 import sys
+import warnings
 from concurrent.futures import ThreadPoolExecutor
 
 from ledfx.config import load_config, load_default_presets, save_config
@@ -9,9 +10,15 @@ from ledfx.effects import Effects
 from ledfx.events import Events, LedFxShutdownEvent
 from ledfx.http_manager import HttpServer
 from ledfx.integrations import Integrations
-from ledfx.utils import RollingQueueHandler, async_fire_and_forget
+from ledfx.utils import (
+    RollingQueueHandler,
+    async_fire_and_forget,
+    currently_frozen,
+)
 
 _LOGGER = logging.getLogger(__name__)
+if currently_frozen():
+    warnings.filterwarnings("ignore")
 
 
 class LedFxCore(object):
@@ -26,9 +33,8 @@ class LedFxCore(object):
             self.loop = asyncio.ProactorEventLoop()
         else:
             self.loop = asyncio.get_event_loop()
-        executor_opts = {"max_workers": self.config.get("max_workers")}
 
-        self.executor = ThreadPoolExecutor(**executor_opts)
+        self.executor = ThreadPoolExecutor()
         self.loop.set_default_executor(self.executor)
         self.loop.set_exception_handler(self.loop_exception_handler)
 
