@@ -6,7 +6,13 @@ import sacn
 import voluptuous as vol
 
 from ledfx.devices import Device
-from ledfx.utils import resolve_destination
+from ledfx.utils import (
+    resolve_destination,
+    turn_wled_off,
+    turn_wled_on,
+    wled_identifier,
+    wled_power_state,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -18,16 +24,14 @@ class E131Device(Device):
         {
             vol.Required(
                 "ip_address",
-                description="Hostname or IP address of the device",
+                description="Hostname or IP address of the device, or "
+                "multicast"
+                " for multicast",
             ): str,
             vol.Required(
                 "pixel_count",
                 description="Number of individual pixels",
             ): vol.All(vol.Coerce(int), vol.Range(min=1)),
-            vol.Optional(
-                "icon_name",
-                description="https://material-ui.com/components/material-icons/",
-            ): str,
             vol.Optional(
                 "universe",
                 description="DMX universe for the device",
@@ -35,7 +39,7 @@ class E131Device(Device):
             ): vol.All(vol.Coerce(int), vol.Range(min=1)),
             vol.Optional(
                 "universe_size",
-                description="Size of each DMX universe. Leave at 510 unless you know what you're doing.",
+                description="Size of each DMX universe. Leave at 510 unless you know what you're doing",
                 default=510,
             ): vol.All(vol.Coerce(int), vol.Range(min=1)),
             vol.Optional(
@@ -64,7 +68,7 @@ class E131Device(Device):
         )
         if span % self._config["universe_size"] == 0:
             self._config["universe_end"] -= 1
-
+        self.WLEDReceiver = False
         self._sacn = None
 
     @property
@@ -72,28 +76,40 @@ class E131Device(Device):
         return int(self._config["pixel_count"])
 
     def activate(self):
+        if self._config["ip_address"].lower() == "multicast":
+            multicast = True
+        else:
+            multicast = False
         if self._sacn:
             raise Exception("sACN sender already started.")
-        # check if ip/hostname resolves okay
-        resolved_dest = resolve_destination(self._config["ip_address"])
-        if not resolved_dest:
-            _LOGGER.warning(
-                f"Cannot resolve destination {self._config['ip_address']}, aborting device {self.name} activation. Make sure the IP/hostname is correct and device is online."
-            )
-            return
+
+        if multicast is False:
+            self.device_ip = resolve_destination(self._config["ip_address"])
+            if not self.device_ip:
+                _LOGGER.warning(
+                    f"Cannot resolve destination {self._config['ip_address']}, aborting device {self.name} activation. Make sure the IP/hostname is correct and device is online."
+                )
+                return
+
+            if wled_identifier(self.device_ip, self.name):
+                self.WLEDReceiver = True
+                self.wled_state = wled_power_state(self.device_ip, self.name)
+                if self.wled_state is False:
+                    turn_wled_on(self.device_ip, self.name)
 
         # Configure sACN and start the dedicated thread to flush the buffer
         # Some variables are immutable and must be called here
-        self._sacn = sacn.sACNsender(source_name=self.id)
+        self._sacn = sacn.sACNsender(source_name=self.name)
         for universe in range(
             self._config["universe"], self._config["universe_end"] + 1
         ):
-            _LOGGER.info("sACN activating universe {}".format(universe))
+            _LOGGER.info(f"sACN activating universe {universe}")
             self._sacn.activate_output(universe)
-            if self._config["ip_address"] is None:
+
+            if self._config["ip_address"] == "multicast":
                 self._sacn[universe].multicast = True
             else:
-                self._sacn[universe].destination = resolved_dest
+                self._sacn[universe].destination = self.device_ip
                 self._sacn[universe].multicast = False
         self._sacn._fps = self._config["refresh_rate"]
         self._sacn.start()
@@ -115,6 +131,9 @@ class E131Device(Device):
         self.flush(np.zeros(self._config["channel_count"]))
         time.sleep(1.5)
 
+        if self.WLEDReceiver is True and self.wled_state is False:
+            turn_wled_off(self.device_ip, self.name)
+
         self._sacn.stop()
         self._sacn = None
         _LOGGER.info("sACN sender stopped.")
@@ -126,9 +145,7 @@ class E131Device(Device):
             raise Exception("sACN sender not started.")
         if data.size != self._config["channel_count"]:
             raise Exception(
-                "Invalid buffer size. ({} != {})".format(
-                    data.size, self._config["channel_count"]
-                )
+                f"Invalid buffer size. {data.size} != {self._config['channel_count']}"
             )
 
         data = data.flatten()
