@@ -1,5 +1,6 @@
 import logging
 import time
+import warnings
 from collections import namedtuple
 from functools import lru_cache
 from math import log
@@ -17,6 +18,20 @@ from ledfx.events import GraphUpdateEvent
 
 _LOGGER = logging.getLogger(__name__)
 
+
+"""
+
+    ***THIS IS SUPER IMPORTANT***
+
+    PYAUDIO BINDINGS ARE APPROACHING END OF LIFE
+    FOR PYTHON 3.8/3.9 WE HAVE TO IGNORE ALL WARNINGS THROWN IN THIS FILE
+    OTHERWISE WE GET A DEPRECIATIONWARNING *EVERY AUDIO SAMPLE*
+
+
+"""
+warnings.filterwarnings("ignore")
+
+
 FrequencyRange = namedtuple("FrequencyRange", "min,max")
 
 FREQUENCY_RANGES = {
@@ -676,11 +691,11 @@ class MelbankInputSource(AudioInputSource):
 
     @lru_cache(maxsize=32)
     def midi_value(self):
-        # If pyaudio is returning null, then this catches it hopefully. Rare error that's hard to reproduce.
+        # If pyaudio is returning null, then we just return 0 for midi_value and wait for the device starts sending audio.
         try:
             return self.pitch_o(self.audio_sample())[0]
         except ValueError:
-            _LOGGER.warning("ValueError - No Audio Data. Retrying...")
+            return 0
 
     @lru_cache(maxsize=32)
     def onset(self):
